/*
 * Copyright (C) 2013 Kaan Onarlioglu <onarliog@ccs.neu.edu>
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Kaan Onarlioglu -- www.onarlioglu.com
 * NEU SecLab      -- seclab.ccs.neu.edu
 *
 * privexec.h, ver.2013.10.13
 *
 * Functions to set up the environment for running PrivExec.
 */

#ifndef PRIVEXEC_H
#define PRIVEXEC_H

#include "utils.h"
#include "perms.h"

/*
 * Configuration file paths. These contain security critical info, so paths must
 * be hardcoded, and access to files must be restricted.
 */
#define PRIVEXEC_USR_MNT_CONF "/etc/privexec/usr_mounts.conf"
#define PRIVEXEC_SYS_MNT_CONF "/etc/privexec/sys_mounts.conf"

/* Secure container mount options. */
#define ECRYPTFS_OPTS "ecryptfs_cipher=aes,ecryptfs_key_bytes=32,ecryptfs_privexec"


/*
 * The below must be called in this exact order.
 */

/* Set up functions. */
void init();
void generate_dir_names();
void create_dirs();
void insert_key();
void fork_privexec();
void mount_containers();
void mount_overlays();
void mount_sys();
void run_privexec( char **);

/* Clean up functions. */
void delete_enc_dirs();
void umount_sys();
void umount_overlays();
void umount_containers();
void remove_key();
void remove_dirs();
void free_memory();

#endif /* PRIVEXEC_H */
